@@ -3,7 +3,7 @@ import xml.etree.ElementTree as ElementTree
 
 from utils import dt, filex
 
-FONT_FAMILY = 'Gill Sans'
+FONT_FAMILY = 'sans-serif'
 DEFAULT_ATTRIB_MAP = {
     'html': {
         'style': 'font-family: %s;' % FONT_FAMILY,
@@ -38,7 +38,10 @@ class _:
 
         attrib = DEFAULT_ATTRIB_MAP.get(tag, {})
         attrib.update(attrib_custom)
-        attrib = dict(zip(attrib.keys(), list(map(str, attrib.values()))))
+        attrib = dict(zip(
+            list(map(lambda k: k.replace('_', '-'), attrib.keys())),
+            list(map(str, attrib.values()))),
+        )
 
         element = ElementTree.Element(tag_real)
         element.attrib = attrib
